<template>
  <ProTabs
    v-model="queryState.mineHireType"
    name="home-tab"
    :showPaneContent="false"
    class="home-tabs"
    isTransparent
    title-gutter="12"
    title-scroll
  >
    <ProTabPane :title="`发布中(${1})`" :pane-key="0"></ProTabPane>
    <ProTabPane :title="`已停止(${1})`" :pane-key="10"></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
  >
    <template #renderItem="{ item }">
      <JobApplicationCard @edit="goEdit" @detail="goDetail"> </JobApplicationCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { JobApplicationCard, ProTabs, ProTabPane } from '@12333/components';
import { RouterPath } from '@/constants';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import { TaskStatus } from '@/constants/task';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  mineHireType: TaskStatus.All,
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'isRecommend', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskByArrange(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskByArrange'],
  }
);

function goPage(routeName: string) {
  Taro.navigateTo({
    url: routeName,
  });
}

function goEdit() {
  goPage(RouterPath.publishTask);
}
function goDetail() {
  goPage(RouterPath.jobApplicationDetail);
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

// .jobApplicationManage-page-wrapper {
// }
</style>
